"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const conf_1 = require("../../services/conf");
const docker_1 = require("../../services/docker");
const eslint_1 = require("../../services/eslint");
const render_1 = require("../../services/render");
const util_1 = require("../../util");
const index_1 = require("./index");
const { join } = path;
class ApplicationCreate extends index_1.default {
    async prepare() {
        await docker_1.default.pull(this.rdc);
        const name = this.rdc.split(':')[0];
        await util_1.default.asyncExec(`mkdir ${conf_1.default.localCacheDir}`);
        const eslintrcPath = join(conf_1.default.cwd, conf_1.default.localCacheDir, '.eslintrc.js');
        await docker_1.default.copy(this.rdc, [{
                from: join(conf_1.default.dockerWorkDirRoot, name, 'app'),
                to: join(conf_1.default.cwd, 'app'),
            }, {
                from: join(conf_1.default.dockerWorkDirRoot, name, 'template', '.eslintrc.js'),
                to: eslintrcPath
            }]);
        await this.getRdcConf();
        await eslint_1.default.installEslintExtends(eslintrcPath);
    }
    async genConfFile() {
        const { appConfName } = conf_1.default;
        const { docs, docker = { ports: [] } } = this.rdcConf;
        await render_1.default.renderTo(join('rda', appConfName.slice(0, -3)), {
            container: this.rdc,
            docs: docs ? docs.url : '',
            ports: JSON.stringify(docker.ports),
        }, appConfName);
    }
    async genExtraFiles() {
        await render_1.default.renderTo(join('rda', 'README'), {
            name: this.name,
            homepage: conf_1.default.homepage,
        }, 'README.md');
        await render_1.default.renderTo('.gitignore', {}, '.gitignore', {
            overwrite: true,
        });
        await eslint_1.default.renderDir();
    }
}
exports.default = ApplicationCreate;
